# Egon
[![Unit Tests](https://github.com/mwvgroup/Egon/actions/workflows/unittests.yml/badge.svg)](https://github.com/mwvgroup/Egon/actions/workflows/unittests.yml)

Egon is a lightweight framework for constructing parallelized analysis pipelines. 

See the docs at https://mwvgroup.github.io/Egon/
